@@ -15,6 +15,12 @@ our $deparse = B::Deparse -> new ();
 
 @options = (
 
+	{
+		name     => 'no_clear_button',
+		label_en => "If true, the [X] button is not shown.",
+		label_ru => " ,   [X] ( )  .",
+	},
+
 	{
 		name     => 'is_total',
 		label_en => "If true, the table row is displayed as a totals line, not ordinary row.",
@@ -1811,7 +1817,7 @@ EO
 
 	{
 		name     => 'draw_form_field_datetime',
-		options  => [qw(name label value off format/$$conf{format_dt} no_time onClose max_len)],
+		options  => [qw(name label value off format/$$conf{format_dt} no_time no_clear_button onClose max_len)],
 		label_en => 'Draws the calendar form input (DHTML from http://dynarch.com/mishoo/calendar.epl).',
 		label_ru => '    "" (DHTML-   http://dynarch.com/mishoo/calendar.epl).',
 		see_also => [qw(draw_form)]
@@ -2064,6 +2070,23 @@ EO
 
 					#######################################
 
+	{
+		name     => 'draw_radio_cell',
+		options  => [qw(name value/1 checked off title attributes)],
+		syn      => <<EO,	
+
+	draw_radio_cell ({
+		name     => "item_number_17",
+		checked  => \$REQUEST {id} == 17,
+	})
+EO
+		label_en => 'Draws table cell containing a radio button.',
+		label_ru => '    -.',
+		see_also => [qw(draw_table)]
+	},
+
+					#######################################
+
 	{
 		name     => 'draw_input_cell',
 		options  => [qw(name label off/0 read_only/0 max_len/$$conf{max_len} size/30 attributes a_class/lnk4)],
