@@ -51,6 +51,12 @@ sub internal_redirect {
 
 ################################################################################
 
+sub args {
+	return $ENV {QUERY_STRING};
+}
+
+################################################################################
+
 sub header_in {
 	my $self = shift;
 	my $q = $self -> {Q};
